import React, { useEffect, useMemo, useRef, useState } from 'react';
import Taro from '@tarojs/taro';
import { View } from '@tarojs/components';
import Item from './Item';
import { useList } from './hooks';
import { classNames, getRect } from './utils';

import './style.less'

export default (props) => {
  const { className, itemClassName, style, gutter = 0, list, render, ...leftProps } = props

  const splitStyle = { width: `${gutter}rpx` }

  const leftBottom = useRef(0)
  const rightBottom = useRef(0)
  const [leftList, leftRef, setLeftList] = useList()
  const [rightList, rightRef, setRightList] = useList()
  const [cursor, setCursor] = useState(0)

  const listRef = useRef([])
  listRef.current = list

  const handleRenderFinish = (direct) => (rect) => {
    const { bottom } = rect

    if (direct === 'left') {
      leftBottom.current = bottom
    } else {
      rightBottom.current = bottom
    }

    setCursor(cursor + 1)
  }
    
  useEffect(() => {
    setCursor(0)
    setLeftList([])
    setRightList([])
    listRef.current = list ? list.slice() : []
  }, [list])

  useEffect(() => {
    const len = !list ? 0 : list.length;
    if (leftRef.current.length + rightRef.current.length >= len) return;

    const item = listRef.current.shift()
    item.__vid = `f-${Math.random().toString(36).substring(2)}`

    if (leftBottom.current <= rightBottom.current) {
      setLeftList([...leftRef.current, item])
    } else {
      setRightList([...rightRef.current, item])
    }
  }, [cursor, list])

  return (
    <View
      style={style}
      className={classNames(className, 'masonry-layout')}
    >
      <View className='masonry-column'>
        {
          leftList.map(item => <Item key={item.__vid} className={itemClassName} item={item} render={render} onRenderFinish={handleRenderFinish('left')} />)
        }
      </View>
      <View className='masonry-split' style={splitStyle} />
      <View className='masonry-column'>
        {
          rightList.map(item => <Item key={item.__vid} className={itemClassName} item={item} render={render} onRenderFinish={handleRenderFinish('right')} />)
        }
      </View>
    </View>
  )
}
